/**
 * Change color format to hex in Pika.
 *
 * @returns Pika format hex URL.
 * @example
 * formatHex()
 * // => 'pika://format/hex'
 * @link https://github.com/superhighfives/pika/blob/main/Pika/Views/HelpView.swift
 */
export function formatHex() {
  return 'pika://format/hex'
}

/**
 * Change color format to RGB in Pika.
 *
 * @returns Pika format RGB URL.
 * @example
 * formatRgb()
 * // => 'pika://format/rgb'
 * @link https://github.com/superhighfives/pika/blob/main/Pika/Views/HelpView.swift
 */
export function formatRgb() {
  return 'pika://format/rgb'
}

/**
 * Change color format to HSB in Pika.
 *
 * @returns Pika format HSB URL.
 * @example
 * formatHsb()
 * // => 'pika://format/hsb'
 * @link https://github.com/superhighfives/pika/blob/main/Pika/Views/HelpView.swift
 */
export function formatHsb() {
  return 'pika://format/hsb'
}

/**
 * Change color format to HSL in Pika.
 *
 * @returns Pika format HSL URL.
 * @example
 * formatHsl()
 * // => 'pika://format/hsl'
 * @link https://github.com/superhighfives/pika/blob/main/Pika/Views/HelpView.swift
 */
export function formatHsl() {
  return 'pika://format/hsl'
}

/**
 * Change color format to LAB in Pika.
 *
 * @returns Pika format LAB URL.
 * @example
 * formatLab()
 * // => 'pika://format/lab'
 * @link https://github.com/superhighfives/pika/blob/main/Pika/Views/HelpView.swift
 */
export function formatLab() {
  return 'pika://format/lab'
}

/**
 * Change color format to OpenGL in Pika.
 *
 * @returns Pika format OpenGL URL.
 * @example
 * formatOpenGL()
 * // => 'pika://format/opengl'
 * @link https://github.com/superhighfives/pika/blob/main/Pika/Views/HelpView.swift
 */
export function formatOpenGL() {
  return 'pika://format/opengl'
}

/**
 * Change color format to OKLCH in Pika.
 *
 * @returns Pika format OKLCH URL.
 * @example
 * formatOklch()
 * // => 'pika://format/oklch'
 * @link https://github.com/superhighfives/pika/blob/main/Pika/Views/HelpView.swift
 */
export function formatOklch() {
  return 'pika://format/oklch'
}
